package com.ynet.life.action;

import com.ynet.gene.comm.http.HttpResource;
import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.gene.data.InvalidArgumentException;
import com.ynet.gene.data.ObjectNotFoundException;
import com.ynet.gene.format.FormatElement;
import com.ynet.gene.format.GENEFormatException;
import com.ynet.life.base.LifeAction;
import com.ynet.life.base.LifeDBAccess;
import com.ynet.life.base.LifeErrorInfo;
import com.ynet.life.base.LifePlatManager;
import com.ynet.life.base.LifeStandard;
import com.ynet.life.base.TEntity;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.HttpCommunicationException;
import com.ynet.life.exception.TranFailException;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.sql.Connection;
import java.util.ArrayList;
import java.util.List;
import java.util.StringTokenizer;
import java.util.Vector;
import org.apache.axis.utils.StringUtils;

/* loaded from: com_ynet_life_action.jar:com/ynet/life/action/HttpCommActionNew.class */
public class HttpCommActionNew extends LifeAction {
    public static final boolean MASK_PASSWORD = true;
    public static final String MASK_BEGIN_TAG = "<password>";
    public static final String MASK_END_TAG = "</password>";
    public static final String MASK_CONTENT = "<password>****</password>";
    private static final int DEFAULT_TIMEOUT = 60000;
    private static final int REQUEST_LENGTH = 8;
    private static final String ERROR_CODE_PACK = "EBLN0010";
    private static final String ERROR_CODE_POOL = "EBLN0011";
    private static final String ERROR_CODE_LOSEDATA = "EBLN0012";
    private static final String ERROR_CODE_TIMEOUT = "EBLN0013";
    private static final String ERROR_CODE_UNPACK = "EBLN0014";
    private static final String ERROR_CODE_GATEWAY = "EBLN0015";
    private String hostCode;
    private String sendFormatName;
    private String receiveFormatName;
    private String recMsgDataName;
    public static final String FIELD_HOST_RETURN_CODE = "hostReturnCode";
    public static final String FIELD_HOST_ERROR_MESSAGE = "hostErrorMessage";

    public String execute(Context context) throws GENEException {
        String readLocalFile = LifeStandard.getBankSettingsValue("readLocalFile");
        if ("true".equals(readLocalFile)) {
            return localMeg(context);
        }
        try {
            String bankId = "";
            if (StringUtils.isEmpty("")) {
                bankId = "070000";
            }
            String httpResource = LifePlatManager.getBankGateway(bankId);
            HttpResource service = (HttpResource) context.getService(httpResource);
            System.out.println("==================================================" + service.getId());
            if (service == null) {
                throw new TranFailException(ERROR_CODE_POOL, "无法获取通讯服务");
            }
            try {
                String head = prepareData(context);
                FormatElement sendFormatElement = context.getFormat(this.sendFormatName);
                if (sendFormatElement == null) {
                    throw new TranFailException(ERROR_CODE_PACK, "发送报文格式未定义");
                }
                try {
                    String sendMessage = (String) sendFormatElement.format(context);
                    if (sendMessage == null) {
                        sendMessage = "";
                    }
                    String tempHSendMessage = null;
                    String tempBSendMessage = null;
                    if (sendMessage.indexOf("<root>") != -1) {
                        tempHSendMessage = sendMessage.substring(0, sendMessage.indexOf("<root>") + 6);
                        String str = sendMessage;
                        tempBSendMessage = str.substring(str.indexOf("<root>") + 6);
                        head = head.substring(head.indexOf("?>") + 2);
                    }
                    String sendMessage2 = String.valueOf(tempHSendMessage) + head + tempBSendMessage;
                    String lenStr = "00000000" + String.valueOf(sendMessage2.getBytes().length);
                    String sendMessage3 = String.valueOf(lenStr.substring(lenStr.length() - REQUEST_LENGTH)) + sendMessage2;
                    print("网银请求报文：\n".concat(String.valueOf(sendMessage3)));
                    try {
                        String receivedMessage = service.sendAndWait(sendMessage3, DEFAULT_TIMEOUT);
                        if (receivedMessage == null || receivedMessage.trim().length() < 88) {
                            throw new TranFailException(ERROR_CODE_LOSEDATA, "返回报文长度异常");
                        }
                        print("网关返回报文：\n".concat(String.valueOf(receivedMessage)));
                        String gwRsResultFlag = receivedMessage.substring(89, 90);
                        if (!"Y".equals(gwRsResultFlag) && receivedMessage.substring(10, 18).startsWith("gw")) {
                            String errorStack = "";
                            try {
                                errorStack = receivedMessage.substring(88);
                            } catch (Exception unused) {
                            }
                            throw new TranFailException(ERROR_CODE_GATEWAY, errorStack);
                        }
                        try {
                            int msgLen = Integer.parseInt(receivedMessage.substring(0, REQUEST_LENGTH));
                            String tmp = receivedMessage.substring(REQUEST_LENGTH);
                            if (msgLen != tmp.length()) {
                                throw new TranFailException(ERROR_CODE_LOSEDATA, "返回报文长度异常");
                            }
                            String receivedMessage2 = receivedMessage.substring(REQUEST_LENGTH);
                            try {
                                if (this.recMsgDataName != null) {
                                    context.setDataValue(this.recMsgDataName, receivedMessage2);
                                } else {
                                    FormatElement receiveFormatElement = context.getFormat(this.receiveFormatName);
                                    if (receiveFormatElement == null) {
                                        throw new TranFailException(ERROR_CODE_UNPACK, "接收报文格式未定义");
                                    }
                                    try {
                                        receiveFormatElement.unFormat(receivedMessage2, context);
                                    } catch (GENEFormatException ex) {
                                        throw new TranFailException(ERROR_CODE_UNPACK, "返回报文解包失败", ex);
                                    }
                                }
                                try {
                                    dealResult(context);
                                    return "0";
                                } catch (TranFailException te) {
                                    Trace.logError("LifeAction", te.getShowMessage(), te);
                                    context.put("GENEException", te);
                                    throw te;
                                }
                            } catch (Exception e) {
                                throw new TranFailException(ERROR_CODE_UNPACK, e);
                            }
                        } catch (NumberFormatException nfe) {
                            throw new TranFailException(ERROR_CODE_LOSEDATA, nfe.getMessage());
                        }
                    } catch (GENEException ex2) {
                        throw new TranFailException(ERROR_CODE_TIMEOUT, "网关通信超时", ex2);
                    }
                } catch (GENEFormatException ex3) {
                    throw new TranFailException(ERROR_CODE_PACK, "发送报文格式化失败", ex3);
                }
            } catch (GENEException ex4) {
                throw new TranFailException(ERROR_CODE_PACK, "准备报头数据出错", ex4);
            }
        } catch (TranFailException te2) {
            Trace.logError("LifeAction", te2.getShowMessage(), te2);
            context.put("GENEException", te2);
            throw new HttpCommunicationException(te2);
        }
    }

    private String localMeg(Context context) throws TranFailException {
        try {
            FormatElement sendFormatElement = context.getFormat(this.sendFormatName);
            if (sendFormatElement == null) {
                Trace.logError("LifeAction", "EBLN0010：发送报文格式未定义");
                throw new TranFailException(ERROR_CODE_PACK, "发送报文格式未定义");
            }
            try {
                String sendMessage = (String) sendFormatElement.format(context);
                print("----上送报文----\n" + sendMessage + "\n");
                String localMessage = readLocalFile();
                print("----返回报文----\n" + localMessage + "\n");
                FormatElement receiveFormatElement = context.getFormat(this.receiveFormatName);
                if (receiveFormatElement == null) {
                    Trace.logError("LifeAction", "EBLN0010：接收报文格式未定义");
                    throw new TranFailException(ERROR_CODE_PACK, "接收报文格式未定义");
                }
                try {
                    receiveFormatElement.unFormat(localMessage, context);
                    return "0";
                } catch (Exception ex) {
                    Trace.logError("LifeAction", "EBLN0010：返回报文解包失败", ex);
                    throw new TranFailException(ERROR_CODE_PACK, "返回报文解包失败", ex);
                }
            } catch (GENEFormatException ex2) {
                Trace.logError("LifeAction", "EBLN0010：发送报文格式化失败", ex2);
                throw new TranFailException(ERROR_CODE_PACK, "发送报文格式化失败", ex2);
            }
        } catch (Exception unused) {
            throw new TranFailException(ERROR_CODE_PACK, "发送报文格式未定义");
        }
    }

    protected List getReqHeadParams() {
        List params = new ArrayList();
        params.add("$gatewayData.gwPkgType,2");
        params.add("$gatewayData.gwTrxCode,8");
        params.add("$gatewayData.gwMsgType,1");
        params.add("$gatewayData.gwReqTime,14");
        params.add("$gatewayData.gwFlwNo,8");
        params.add("$gatewayData.gwReqChannel,2");
        params.add("$gatewayData.gwBrchETellerNo,8");
        params.add("$gatewayData.gwRsCode,6");
        params.add("$gatewayData.gwReserveMe,32");
        params.add("$gatewayData.gwRsResultFlag,1");
        params.add("$gatewayData.hBrchNo,3");
        params.add("$gatewayData.hBrchClrNo,7");
        params.add("$gatewayData.hBrchETellerNo,8");
        return params;
    }

    protected String getGWHead(Context context, List headParams) throws GENEException {
        StringBuffer temp;
        StringBuffer result = new StringBuffer();
        if (headParams != null) {
            for (int i = 0; i < headParams.size(); i++) {
                String param = (String) headParams.get(i);
                boolean isField = param.startsWith("$");
                int idx = param.indexOf(",");
                int len = Integer.parseInt(param.substring(idx + 1).trim());
                if (isField) {
                    temp = new StringBuffer((String) context.getDataValue(param.substring(1, idx)));
                } else {
                    temp = new StringBuffer(param.substring(0, idx));
                }
                if (temp.length() < len) {
                    for (int k = temp.length(); k < len; k++) {
                        temp.append(" ");
                    }
                    result.append(temp);
                } else if (temp.length() > len) {
                    result.append(temp.substring(0, len));
                } else {
                    result.append(temp);
                }
            }
        }
        return result.toString();
    }

    protected String prepareData(Context context) throws GENEException {
        String language;
        String sequenceNo = LifeStandard.getServerTime("yyyyMMdd");
        Connection connection = null;
        try {
            try {
                connection = LifeDBAccess.getConnection("ebank_ds");
                String sequenceNo2 = String.valueOf(sequenceNo) + LifeDBAccess.getSequenceNo(connection, "REQ_PACK_FLOW_NO");
                LifeDBAccess.releaseConnection("ebank_ds", connection);
                try {
                    language = (String) context.getDataValue(TEntity.language);
                } catch (Exception unused) {
                    language = "ZH_CN";
                }
                if (StringUtils.isEmpty(language)) {
                    language = "ZH_CN";
                    Trace.logInfo("LifeAction", "获取语言标识失败,默认为ZH_CN");
                }
                context.put("head_sendFlow", sequenceNo2);
                context.put("head_channel", "03");
                context.put("head_language", language);
                context.put("head_bsncode", this.hostCode);
                context.put("head_tranDate", LifeStandard.getServerTime("yyyyMMdd"));
                context.put("head_tranTime", LifeStandard.getServerTime("HHmmss"));
                String customerId = (String) context.get("customerId");
                if (customerId == null || customerId.trim().equals("")) {
                    context.put("head_custNo", "9999999999");
                } else {
                    context.put("head_custNo", customerId);
                }
                context.put("head_custId", "0");
                context.put("head_oprater", "e931");
                context.put("head_bankId", context.get("bankId"));
                context.put("head_customerId", context.get("customerId"));
                context.put("head_userId", context.get("userId"));
                return (String) context.getFormat("PUBSendFormat").format(context);
            } catch (GENEException empe) {
                Trace.logError("LifeAction", empe.getMessage(), empe);
                throw empe;
            }
        } catch (Throwable th) {
            LifeDBAccess.releaseConnection("ebank_ds", connection);
            throw th;
        }
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v21, types: [int] */
    /* JADX WARN: Type inference failed for: r0v24, types: [com.ynet.gene.core.Context] */
    private void dealResult(Context context) throws TranFailException {
        int result;
        String hostReturnCode = (String) context.get("hostReturnCode");
        if (hostReturnCode == null) {
            throw new TranFailException("EBLN0000", "无法获取交易结果代码hostReturnCode");
        }
        try {
            InvalidArgumentException parseInt = Integer.parseInt(hostReturnCode);
            result = parseInt;
            if (parseInt == 0) {
                try {
                    parseInt = context;
                    parseInt.setDataValue("hostReturnCode", "0");
                } catch (InvalidArgumentException e) {
                    parseInt.printStackTrace();
                } catch (ObjectNotFoundException e2) {
                    parseInt.printStackTrace();
                }
            }
        } catch (NumberFormatException unused) {
            result = -1;
        }
        if (result != 0) {
            String hostErrorMessage = null;
            try {
                hostErrorMessage = (String) context.getDataValue("hostErrorMessage");
            } catch (GENEException ex) {
                Trace.logWarning("LifeAction", ex.getMessage(), ex);
            }
            if (hostErrorMessage == null) {
                LifeErrorInfo error = LifeStandard.getErrorInfo(hostReturnCode);
                if (error == null) {
                    throw new TranFailException(hostReturnCode, "未知的错误代码");
                }
                hostErrorMessage = error.getShowMsg();
            }
            TranFailException ex2 = new TranFailException(hostReturnCode, hostErrorMessage);
            context.put("GENEException", ex2);
            throw ex2;
        }
    }

    private String maskMessage(String message) {
        Vector passVector = getSegmentsStr(LifeStandard.getBankSettingsValue("PasswordFields_Masked"), ",");
        for (int i = 0; i < passVector.size(); i++) {
            String subStr = ((String) passVector.elementAt(i)).trim();
            if (!"".equals(subStr)) {
                String subStr2 = "<" + subStr + ">";
                String subStrEnd = "</" + subStr + ">";
                String mask_content = String.valueOf(subStr2) + "******" + subStrEnd;
                int tagBeginPos = message.indexOf(subStr2);
                if (tagBeginPos >= 0) {
                    int tagEndPos = message.indexOf(subStrEnd) + subStrEnd.length();
                    return String.valueOf(message.substring(0, tagBeginPos)) + mask_content + message.substring(tagEndPos);
                }
            }
        }
        return message;
    }

    private String readLocalFile() {
        InputStreamReader read = null;
        BufferedReader in = null;
        String message = null;
        FileInputStream file = null;
        try {
            try {
                String rootPath = LifeStandard.getRootPath();
                String virtualHostFileName = String.valueOf(rootPath) + "WEB-INF/virtualhost/" + this.hostCode + ".txt";
                File virtualHostFile = new File(virtualHostFileName);
                if (!virtualHostFile.exists()) {
                    Trace.logError("LifeFile", "读取本地文件出错");
                }
                file = new FileInputStream(virtualHostFile);
                read = new InputStreamReader(file);
                in = new BufferedReader(read);
                StringBuffer sb = new StringBuffer();
                while (true) {
                    String line = in.readLine();
                    if (line == null) {
                        break;
                    }
                    sb = sb.append(line);
                }
                message = sb.toString();
                try {
                    in.close();
                    read.close();
                    file.close();
                } catch (IOException unused) {
                }
            } catch (Exception e) {
                Trace.logError("LifeFile", "读取本地文件出错", e);
                if (in != null) {
                    try {
                        in.close();
                    } catch (IOException unused2) {
                    }
                }
                if (read != null) {
                    read.close();
                }
                if (file != null) {
                    file.close();
                }
            }
            return message;
        } catch (Throwable th) {
            if (in != null) {
                try {
                    in.close();
                } catch (IOException unused3) {
                    throw th;
                }
            }
            if (read != null) {
                read.close();
            }
            if (file != null) {
                file.close();
            }
            throw th;
        }
    }

    private void print(String message) {
        Trace.logDebug("LifeHTTP", maskMessage(message));
    }

    public void setHostCode(String hostCode) {
        this.hostCode = hostCode;
    }

    public void setSendFormatName(String sendFormatName) {
        this.sendFormatName = sendFormatName;
    }

    public void setReceiveFormatName(String receiveFormatName) {
        this.receiveFormatName = receiveFormatName;
    }

    public void setRecMsgDataName(String recMsgDataName) {
        this.recMsgDataName = recMsgDataName;
    }

    private static Vector getSegmentsStr(String str, String token) {
        Vector vocter = new Vector(1);
        StringTokenizer st = new StringTokenizer(str, token);
        while (st.hasMoreTokens()) {
            String des = st.nextToken();
            vocter.addElement(des);
        }
        return vocter;
    }
}
